@@ -15,7 +15,7 @@ require AutoLoader;
 @EXPORT = qw(
 	
 );
-$VERSION = '1.46';
+$VERSION = '1.47';
 
 sub new {
   my ($pkg, $data, $header, $type, $enforceCheck) = @_;
@@ -677,38 +677,6 @@ sub sort_v0 {
   return 1;
 } 
   
-sub sort2 {
-    my $self = shift;
-    my @cols = @_;
-    confess "Parameters be in groups of three!\n" if ($#cols % 3 != 2);
-    foreach (0 .. ($#cols/3)) {
-      my $col = $self->checkOldCol($cols[$_*3]);
-      return undef unless defined $col;
-      $cols[$_*3]=$col;
-    }
-    my $func = sub {
-        my $res = 0;
-        for (my $i=0; $i<=$#cols; $i+=3) {
-            my $predicate;
-            if ($cols[$i+1] == 0) {
-                $predicate = sub { $_[0] <=> $_[1] };
-            } elsif ($cols[$i+1] == 1) {
-                $predicate = sub { $_[0] cmp $_[1] };
-            } elsif (ref $cols[$i+1] eq 'CODE') {
-                $predicate = $cols[$i+1];
-            } else {
-                confess "Sort method should be 0 (numerical), 1 (other type), or a subroutine reference!\n";
-            }
-            $res ||= $predicate->($cols[$i+2] ? ($b->[$cols[$i]], $a->[$cols[$i]]) : ($a->[$cols[$i]], $b->[$cols[$i]]));
-            return $res unless $res==0;
-        }
-        return $res;
-    };
-    $self->rotate() if $self->{type};
-    $self->{data} = [sort $func @{$self->{data}}];
-    return 1;
-}
-
 sub sort {
     my $self = shift;
     my @cols = @_;
@@ -726,7 +694,8 @@ sub sort {
       } elsif ($cols[$i+1] == 1) {
         $mysub = ($cols[$i+2]? sub { $_[1] cmp $_[0] } : sub { $_[0] cmp $_[1] });
       } elsif (ref $cols[$i+1] eq 'CODE') {
-        $mysub = ($cols[$i+2]? sub { $cols[$i+1]->($_[1], $_[0]) } : $cols[$i+1]);
+        my $predicate=$cols[$i+1];
+        $mysub = ($cols[$i+2]? sub { $predicate->($_[1], $_[0]) } : $predicate);
       } else {
         confess "Sort method should be 0 (numerical), 1 (other type), or a subroutine reference!\n";
       }
@@ -1682,13 +1651,11 @@ optional named argument OS specifies under which operating system the CSV file w
 
 The following example reads a DOS format CSV file and writes a MAC format:
 
-$t = Data::Table:fromCSV('A_DOS_CSV_FILE.csv', 1, undef, {OS=>1});
-
-$t->csv(1, {OS=>2, file=>'A_MAC_CSV_FILE.csv'});
-
-open(SRC, 'A_DOS_CSV_FILE.csv') or die "Cannot open A_DOS_CSV_FILE.csv to read!";
-$t = Data::Table::fromCSV(\*SRC, 1);
-close(SRC);
+  $t = Data::Table:fromCSV('A_DOS_CSV_FILE.csv', 1, undef, {OS=>1});
+  $t->csv(1, {OS=>2, file=>'A_MAC_CSV_FILE.csv'});
+  open(SRC, 'A_DOS_CSV_FILE.csv') or die "Cannot open A_DOS_CSV_FILE.csv to read!";
+  $t = Data::Table::fromCSV(\*SRC, 1);
+  close(SRC);
 
 =item table table::fromCSVi ($name, $includeHeader = 1, $header = ["col1", ... ])
 
@@ -1955,20 +1922,20 @@ the authors feel inplace sorting is more natural.
 
 table::sort can take a user supplied operator, this is useful when neither numerical nor alphabetic order is correct.
 
-$Well=["A_1", "A_2", "A_11", "A_12", "B_1", "B_2", "B_11", "B_12"];
-$t = new Data::Table([$Well], ["PlateWell"], 1);
-$t->sort("PlateWell", 1, 0);
-print join(" ", $t->col("PlateWell"));
-# prints: A_1 A_11 A_12 A_2 B_1 B_11 B_12 B_2
-# in string sorting, "A_11" and "A_12" appears before "A_2";
-my $my_sort_func = sub {
-  my @a = split /_/, $_[0];
-  my @b = split /_/, $_[1];
-  my $res = ($a[0] cmp $b[0]) || (int($a[1]) <=> int($b[1]));
-};
-$t->sort("PlateWell", $my_sort_func, 0);
-print join(" ", $t->col("PlateWell"));
-# prints the correct order: A_1 A_2 A_11 A_12 B_1 B_2 B_11 B_12
+  $Well=["A_1", "A_2", "A_11", "A_12", "B_1", "B_2", "B_11", "B_12"];
+  $t = new Data::Table([$Well], ["PlateWell"], 1);
+  $t->sort("PlateWell", 1, 0);
+  print join(" ", $t->col("PlateWell"));
+  # prints: A_1 A_11 A_12 A_2 B_1 B_11 B_12 B_2
+  # in string sorting, "A_11" and "A_12" appears before "A_2";
+  my $my_sort_func = sub {
+    my @a = split /_/, $_[0];
+    my @b = split /_/, $_[1];
+    my $res = ($a[0] cmp $b[0]) || (int($a[1]) <=> int($b[1]));
+  };
+  $t->sort("PlateWell", $my_sort_func, 0);
+  print join(" ", $t->col("PlateWell"));
+  # prints the correct order: A_1 A_2 A_11 A_12 B_1 B_2 B_11 B_12
 
 =item table table::match_pattern ($pattern, $countOnly)
 
